@@ -1,4 +1,4 @@
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 import os
 import shutil
@@ -15,7 +15,7 @@ def tests(session):
 
     # install testing requirements and local dependencies
     session.install("-r", "dev-requirements.txt")
-    session.install("-r", "requirements.txt")
+    session.install("-r", "requirements.txt", "-U")
     session.install(f"/tmp/pandas-ml-common-{__version__}.zip")
     session.install(f"/tmp/pandas-ml-utils-{__version__}.zip")
     session.install(f"/tmp/pandas-ta-quant-{__version__}.zip")
